@@ -1,4 +1,4 @@
-# $Id: Constraints.pm 432 2005-03-18 02:09:30Z claco $
+# $Id: Constraints.pm 547 2005-06-25 02:09:43Z claco $
 package Handel::Constraints;
 use strict;
 use warnings;
@@ -7,7 +7,7 @@ use vars qw(@EXPORT_OK %EXPORT_TAGS);
 BEGIN {
     use base 'Exporter';
     use Handel::ConfigReader;
-    use Handel::Constants qw(:cart);
+    use Handel::Constants qw(:cart :checkout :order);
     use Handel::Exception;
     use Handel::L10N qw(translate);
 };
@@ -17,6 +17,8 @@ BEGIN {
                 &constraint_uuid
                 &constraint_cart_type
                 &constraint_currency_code
+                &constraint_checkout_phase
+                &constraint_order_type
 );
 
 %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -24,7 +26,8 @@ BEGIN {
 my %codes;
 
 sub constraint_quantity {
-    my ($value, $object, $column, $changing) = @_;
+    my $value = defined $_[0] ? shift : '';
+    my ($object, $column, $changing) = @_;
 
     my $cfg    = Handel::ConfigReader->new();
     my $max    = $cfg->{'HandelMaxQuantity'};
@@ -44,13 +47,13 @@ sub constraint_quantity {
 };
 
 sub constraint_price {
-    my $value = shift;
+    my $value = defined $_[0] ? shift : '';
 
     return ($value =~ /^\d{1,5}(\.\d{1,2})?$/ && $value > 0);
 };
 
 sub constraint_uuid {
-    my $value = shift;
+    my $value = defined $_[0] ? shift : '';
 
     return ($value =~ m/  ^[0-9a-f]{8}-
                            [0-9a-f]{4}-
@@ -61,7 +64,7 @@ sub constraint_uuid {
 };
 
 sub constraint_cart_type {
-    my $value = shift;
+    my $value = defined $_[0] ? shift : '';
 
     return if $value !~ /[0-9]/;
 
@@ -72,7 +75,7 @@ sub constraint_cart_type {
 };
 
 sub constraint_currency_code {
-    my $value = uc(shift);
+    my $value = defined $_[0] ? uc(shift) : '';
 
     return  unless ($value =~ /^[A-Z]{3}$/);
 
@@ -87,6 +90,29 @@ sub constraint_currency_code {
     return 1;
 };
 
+sub constraint_checkout_phase {
+    my $value = defined $_[0] ? shift : '';
+
+    return if $value !~ /[0-9]/;
+
+    if ($value != CHECKOUT_PHASE_INITIALIZE && $value != CHECKOUT_PHASE_VALIDATE &&
+        $value != CHECKOUT_PHASE_AUTHORIZE && $value != CHECKOUT_PHASE_DELIVER) {
+        return 0;
+    };
+    return 1;
+};
+
+sub constraint_order_type {
+    my $value = defined $_[0] ? shift : '';
+
+    return if $value !~ /[0-9]/;
+
+    if ($value != ORDER_TYPE_SAVED && $value != ORDER_TYPE_TEMP) {
+        return 0;
+    };
+    return 1;
+};
+
 1;
 __END__
 
@@ -153,6 +179,16 @@ conforms to:
 
     /^[A-Z]{3}$/
 
+=head2 constraint_checkout_phase
+
+Returns 1 if the value passed is one of the C<CHECKOUT_PHASE_*> constants,
+otherwise it returns C<undef>.
+
+=head2 constraint_order_type
+
+Returns 1 if the value passed is C<ORDER_TYPE_SAVED> or C<ORDER_TYPE_TEMP>,
+otherwise it returns C<undef>.
+
 =head1 EXPORT_TAGS
 
 =head2 :all
